#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.2
visibility:           public
id:                   yesod-static-1.6.1.2-CfkCS4e4YB33nJ5anA9GU
key:                  yesod-static-1.6.1.2-CfkCS4e4YB33nJ5anA9GU
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  a834e70c5ba8d6fd4c29e52a2e9052da
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.2-CfkCS4e4YB33nJ5anA9GU
depends:
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    blaze-builder-0.4.4.1-4JIC4S953rP8VbASrBgFEC bytestring-0.11.5.3
    conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT containers-0.6.7
    crypton-1.0.5-AZiRYciVzaiGzchrza0W2Y
    crypton-conduit-0.2.3-5PZrVRMjjOX1J3xh5J3OC1
    css-text-0.1.3.0-31T7CjaUWr3As7sNW3C98z
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hjsmin-0.2.1-6GvkpzAYS9GDJki0difJKa
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN process-1.6.19.0
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-CVij6K5GN6q30I6j86A2Op
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    wai-3.2.4-DLXs1orvvdJGWv69GIPJL5
    wai-app-static-3.1.9.1-BYreF6tuKAC3hrpdiP9PQM
    yesod-core-1.6.28.0-Ft208kyeYKA4xNwEDVz5uV

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

